@@ -20,7 +20,8 @@ Released under MIT license.
 """
 import inspect
 import re
-from sqlalchemy import and_, or_, DateTime, Date, Interval, Integer, Binary, MetaData, desc as _desc
+from sqlalchemy import and_, or_, DateTime, Date, Interval, Integer, Binary, MetaData, desc as _desc, func
+from sqlalchemy import String
 from sqlalchemy.engine import Engine
 from sqlalchemy.orm.session import Session
 from sqlalchemy.orm.scoping import ScopedSession
@@ -138,6 +139,16 @@ class SAORMProvider(IProvider):
             return getattr(self._relationship_local_side(field)[0], 'nullable')
         return getattr(field, 'nullable', True)
 
+    def is_string(self, entity, name):
+        field = self.get_field(entity, name)
+        if isinstance(field, PropertyLoader):
+            field = self._relationship_local_side(field)[0]
+        if isinstance(field, SynonymProperty):
+            field = self.get_field(entity, field.name)
+
+        #should cover Unicode, UnicodeText, Text and so on by inheritance
+        return isinstance(field.type, String)
+
     def get_primary_fields(self, entity):
         #sometimes entities get surrounded by functions, not sure why.
         if inspect.isfunction(entity):
@@ -243,6 +254,10 @@ class SAORMProvider(IProvider):
         field = getattr(entity, field_name)
         return [ col.name for col in self._relationship_local_side(field.property)]
 
+    def is_query(self, entity, value):
+        """determines if a field is a query instead of actual list of data"""
+        return isinstance(value, Query)
+
     def is_unique(self, entity, field_name, value):
         field = getattr(entity, field_name)
         try:
@@ -380,7 +395,7 @@ class SAORMProvider(IProvider):
         return r
 
     def get_field_default(self, field):
-        if isinstance(field, Column) and field.default and getattr(field.default, 'arg', None):
+        if isinstance(field, Column) and field.default and getattr(field.default, 'arg', None) is not None:
             if isinstance(field.default.arg, str) or \
                isinstance(field.default.arg, unicode) or \
                isinstance(field.default.arg, int) or \
@@ -407,7 +422,8 @@ class SAORMProvider(IProvider):
         return self.dictify(obj, fields, omit_fields)
 
     def query(self, entity, limit=None, offset=None, limit_fields=None,
-            order_by=None, desc=False, field_names=[], filters={}, **kw):
+            order_by=None, desc=False, field_names=[], filters={},
+            substring_filters=[], **kw):
         query = self.session.query(entity)
 
         filters = self._modify_params_for_dates(entity, filters)
@@ -418,7 +434,10 @@ class SAORMProvider(IProvider):
             if self.is_relation(entity, field_name) and isinstance(value, list):
                 value = value[0]
                 query = query.filter(field.contains(value))
-            else: 
+            elif field_name in substring_filters and self.is_string(entity, field_name):
+                escaped_value = re.sub('[\\\\%\\[\\]_]', '\\\\\g<0>', value.lower())
+                query = query.filter(func.lower(field).contains(escaped_value, escape='\\'))
+            else:
                 query = query.filter(field==value) 
 
         count = query.count()
