@@ -455,6 +455,12 @@ class TestMGORMProvider(SproxTest):
     def test_isbinary_related(self):
         assert not self.provider.is_binary(User, 'groups')
 
+    def test_isbinary(self):
+        assert self.provider.is_binary(File, 'data')
+
+    def test_is_query_not_a_query(self):
+        assert self.provider.is_query(File, None) == False
+
     def test_binary_create(self):
         fs = "fake_content"
 
@@ -642,6 +648,33 @@ class TestMGORMProvider(SproxTest):
         cnt, r = self.provider.query(Town, filters={'name':'Golden'})
         eq_([t.name for t in r], [u'Golden']), r
 
+    def test_query_filters_substring(self):
+        cnt, r = self.provider.query(Town, filters={'name':'old'}, substring_filters=['name'])
+        eq_([t.name for t in r], [u'Golden']), r
+
+    def test_query_filters_substring_escaping(self):
+        cnt, r = self.provider.query(Town, filters={'name':'o.*l.*d'}, substring_filters=['name'])
+        eq_(r, []), r
+
+    def test_query_filters_substring_related(self):
+        cnt, r = self.provider.query(Town, filters={'users':'this_does_not_work'}, substring_filters=['users'])
+        eq_(r, []), r
+
+    def test_query_filters_substring_insensitive(self):
+        cnt, r = self.provider.query(Town, filters={'name':'gold'}, substring_filters=['name'])
+        eq_([t.name for t in r], [u'Golden']), r
+
+    def test_query_filters_substring_disabled(self):
+        cnt, r = self.provider.query(Town, filters={'name':'old'}, substring_filters=[])
+        eq_(r, [])
+
+    def test_query_filters_substring_notstring(self):
+        cnt, towns = self.provider.query(Town)
+        cnt, r = self.provider.query(Town, filters={'_id':towns[0]._id}, substring_filters=['_id'])
+        eq_([t.name for t in r], [towns[0].name])
+        cnt, r = self.provider.query(Town, filters={'_id':'this_is_the_id'}, substring_filters=['_id'])
+        eq_(r, [])
+
     # expected failure; needs updatable RelationProperty
     @raises(TypeError)
     def test_update(self):
